#! /bin/sh
#############################################################################
# $MAPPER_DIR/MapperEnv.sh: source to setup mapper sh/bash path,env
#############################################################################
# 09/03/01 -- begin
# ...
# 10/09/06 -- better path order handling
# 11/05/12 -- fix extra colon in {DY}LD_LIBRARY_PATH (now only Linux)
# 13/01/22 -- don't do Darwin version test on Linux
# 13/04/13 -- comment out freetype libpath (now static), fix setuptcl 8.4->8.5!
# 13/08/17 -- if Linux, add local bitmap fonts for new xft-less tk, ->lib/fonts
# 14/02/02 -- port to sh, tcl setup like FreeSurferEnv.sh (avoids source csh)
# 14/09/06 -- Linux add to LD_LIBRARY_PATH for libjpeg62 for run on newer
# 16/03/22 -- MAPPER_LIBRARY_PATH fix allscripts MacOSX 10.11 noenv2subshell
#TODO: only setenv MAPPER_LIBRARY_PATH (inline pass only)

### report current shell (next works tcsh/bash, Darwin/Linux/IRIX)
echo ""
echo -n "MapperEnv.sh requires sh/bash -- current shell: "
ps -p$$ | grep sh | awk '{print $4}'
echo ""

### to source this file from anywhere, comment-in/edit next line to install dir
#export MAPPER_DIR=/usr/local/mapper
### *or* "export MAPPER_DIR=/your/install/dir" before source'ing

#############################################################################
### prevent execute
## N.B.: still broken: this prevents source inside script since $0=scriptname
#if [ $0 != "bash" ] && [ $0 != "sh" ] && [ $0 != "-bash" ] && \
#   [ $0 != "-sh" ]; then
#  echo "MapperEnv.sh: ### source file (exec'ing it has no effect on env)"
#  echo ""
#  echo "use: source MapperEnv.sh"
#  echo ""
#  exit      # not return because (hopefully) was exec'd
#fi

### warn pre-10.5 MacOSX needs xterm
if [ `uname` = "Darwin" ]; then
  rele=`uname -r`
  needxterm=0
  case "$rele" in 8.*.*) needxterm=1 ;; esac
  if [ $TERM != "xterm" ] && [ $needxterm = 1 ]; then
    echo "MapperEnv.sh: ### on MacOSX 10.4: only works from xterm in X11.app"
  fi
fi
unset rele needxterm

### warn can't find xdpyinfo
if [ "`which xdpyinfo`" == "xdpyinfo: Command not found." ]; then
  echo "MapperEnv.sh: ### xdpyinfo not on path, needed by mapper (in xterm?)"
fi

### if source local, set/reset MAPPER_DIR to here, else use existing if set
if [ -e ./MapperEnv.sh ]; then
  if [ -z "$MAPPER_DIR" ]; then
    echo "MapperEnv.sh: MAPPER_DIR set to: `pwd`"
  else
    echo "MapperEnv.sh: MAPPER_DIR reset to: `pwd`"
  fi
  export MAPPER_DIR=`pwd`
else   # source'ing from somewhere else, use MAPPER_DIR if exists
  if [ -z "$MAPPER_DIR" ]; then
    echo "MapperEnv.sh: ### edit 'export MAPPER_DIR=...' line to inst dir"
    return    # we are sourcing: don't exit current shell
  else   # MAPPER_DIR set/commented-in above or present in user's env
    echo "MapperEnv.sh: MAPPER_DIR set to: $MAPPER_DIR"
  fi
fi

### find specific architecture
if [ ! -e $MAPPER_DIR/bin/noarch/getonearch ]; then
  echo "MapperEnv.sh: ### can't find $MAPPER_DIR/bin/noarch/getonearch (script)"
  return
fi
onearch=`$MAPPER_DIR/bin/noarch/getonearch`
if [ $onearch = "unknown" ]; then
  echo "MapperEnv.sh: ### don't know this arch:"
  uname -a
  unset onearch
  return
fi
sys=`uname -s`

### begin font path addition (if local xserver)
if [ -z $SSH_CLIENT ] && [ -z $SSH_TTY ]; then
  if [ $sys = "Linux" ]; then  # was check lsb_release, but unreliable Ubuntu
    echo \
      "-----------------------------------------------------------------------"
    echo "mapper font changes:"
    mapperfontdir=$MAPPER_DIR/lib/fonts/ISO8859-2/75dpi
    echo " xset fp default (reset to default)"  # no bloat
    xset fp default
    echo " xset +fp $mapperfontdir"
    xset +fp $mapperfontdir
    echo " xset fp rehash"
    xset fp rehash
    unset mapperfontdir
  fi
  if [ $sys == "Darwin" ]; then
    echo "[no X font change for Darwin]"
  fi
fi

### begin env additions
echo "-----------------------------------------------------------------------"
echo "mapper setenv changes:"
echo " MAPPER_DIR=$MAPPER_DIR"

### for mapper scripts
export MAPPERPROG=$MAPPER_DIR/bin/$onearch/mapper
echo " MAPPERPROG=$MAPPERPROG"

### add Tcl/Tk/Tix textlibs to setenv
export TCL_LIBRARY=$MAPPER_DIR/tcltktix/lib/noarch/tcl8.5
echo " TCL_LIBRARY=$TCL_LIBRARY"
export TK_LIBRARY=$MAPPER_DIR/tcltktix/lib/noarch/tk8.5
echo " TK_LIBRARY=$TK_LIBRARY"

### gather dirs for ${DY}LD_LIBRARY_PATH adjust
# add Tcl/Tk/Tix (omit $MAPPER_DIR/freetype-2.4.4/lib/$onearch since static)
addldpathlist=" \
  $MAPPER_DIR/tcltktix/lib/$onearch \
"
# libjpeg62 for newer OS
if [ $sys = "Linux" ]; then
  addldpathlist=" \
    $addldpathlist \
    $MAPPER_DIR/lib/$onearch \
  "
fi

### if {DY}LD_LIBRARY_PATH exists, split/save (tr won't work w/dirs w/spaces)
currldpathlist=""
if [ $sys = "Darwin" ]; then
  echo " pre-appended to DYLD_LIBRARY_PATH:"
  if [ ! -z "$DYLD_LIBRARY_PATH" ]; then   # colon-sep to space-sep
    if [ `echo $DYLD_LIBRARY_PATH | grep -c " "` = 1 ]; then
      echo "MapperEnv.sh: ### DYLD_LIBRARY_PATH dirs w/spaces  ...quitting"
      return
    fi
    currldpathlist=`echo $DYLD_LIBRARY_PATH | tr ':' ' '`
  fi
fi
if [ $sys = "Linux" ]; then
  echo " pre-appended to LD_LIBRARY_PATH:"
  if [ ! -z "$LD_LIBRARY_PATH" ]; then
    if [ `echo $LD_LIBRARY_PATH | grep -c " "` = 1 ]; then
      echo "MapperEnv.sh: ### LD_LIBRARY_PATH dirs w/spaces  ...quitting"
      return
    fi
    currldpathlist=`echo $LD_LIBRARY_PATH | tr ':' ' '`
  fi
fi
if [ $sys = "IRIX" ] || [ $sys = "IRIX64" ]; then
  echo " pre-appended to LD_LIBRARYN32_PATH:"
  if [ ! -z "$LD_LIBRARYN32_PATH" ]; then #also: LD_LIBRARY{64}_PATH
    if [ `echo $LD_LIBRARYN32_PATH | grep -c " "` = 1 ]; then
      echo "MapperEnv.sh: ### LD_LIBRARYN32_PATH dirs w/spaces  ...quitting"
      return
    fi
    currldpathlist=`echo $LD_LIBRARYN32_PATH | tr ':' ' '`
  fi
fi

### make new colon separated LIBRARY path
newldpathlist=""
if [ "$currldpathlist" = "" ]; then
  # empty: make new
  i=1
  for addldpath in $addldpathlist; do
    if [ $i = 1 ]; then
      newldpathlist="$addldpath"
    else
      newldpathlist="${addldpath}:${newldpathlist}"
    fi
    echo "  + $addldpath"
    i=`expr $i + 1`
  done
else
  # strip new members already there (maybe behind) (no goto)
  for currldpath in $currldpathlist; do
    found=0
    for addldpath in $addldpathlist; do
      if [ $currldpath = $addldpath ]; then found=1; fi
    done
    if [ $found = 0 ]; then
      if [ "$newldpathlist" = "" ]; then
        newldpathlist="${currldpath}"
      else
        newldpathlist="${newldpathlist}:${currldpath}"
      fi
    fi
  done
  # add new members to front
  for addldpath in $addldpathlist; do
    newldpathlist="${addldpath}:${newldpathlist}"
    echo "  + $addldpath"
  done
fi
if [ $sys = "Darwin" ]; then
  export DYLD_LIBRARY_PATH="$newldpathlist"
  export MAPPER_LIBRARY_PATH="$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$DYLD_LIBRARY_PATH'
fi
if [ $sys = "Linux" ]; then
  export LD_LIBRARY_PATH="$newldpathlist"
  export MAPPER_LIBRARY_PATH="$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARY_PATH'
fi
if [ $sys = "IRIX" ]; then
  export LD_LIBRARYN32_PATH="$newldpathlist"
  export MAPPER_LIBRARYN32_PATH="$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARYN32_PATH'
fi
if [ $sys = "IRIX64" ]; then
  export LD_LIBRARYN32_PATH="$newldpathlist"
  export MAPPER_LIBRARYN32_PATH="$newldpathlist"
  echo ' MAPPER_LIBRARY_PATH=$LD_LIBRARYN32_PATH'
fi
unset i currldpath currldpathlist addldpath addldpathlist newldpathlist

### begin $PATH additions
echo "-----------------------------------------------------------------------"
echo "pre-appended to csh path:"

### add mapper binary and scripts dirs to beginning of $path
addpathlist="\
    $MAPPER_DIR/tcltktix/bin/$onearch \
    $MAPPER_DIR/bin/$onearch \
    $MAPPER_DIR/bin/noarch \
    $MAPPER_DIR/lib/scripts \
"   # last ends up most front
# strip new members already there (maybe behind)
if [ `echo $PATH | grep -c " "` = 1 ]; then
  echo "MapperEnv.sh: ### PATH dirs w/spaces  ...quitting"
  return
fi
currpathlist=`echo $PATH | tr ':' ' '` # colon->space (won't work dir w/space)
newpathlist=""
for currpath in $currpathlist; do
  found=0
  for addpath in $addpathlist; do
    if [ $currpath = "$addpath" ]; then found=1; fi
  done
  if [ $found = 0 ]; then
    newpathlist="${newpathlist}:${currpath}"  # keep order
  fi
done
# add new members to front
for addpath in $addpathlist; do
  newpathlist="${addpath}:${newpathlist}"
  echo "  + $addpath"
done
export PATH="$newpathlist"
unset currpath currpathlist addpath addpathlist newpathlist
unset onearch

echo "-----------------------------------------------------------------------"
echo ""

### old setup Xlib tcl if Mac (only csh, now ported/included above)
#if [ $sys == "Darwin" ]; then
#  setuptcl=$MAPPER_DIR/tcltktix/bin/noarch/setuptcl.sh
#  if [ -e $setuptcl ]; then source $setuptcl; fi
#fi
#unset setuptcl

